package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseDeviceParamMapper;
import com.aucma.base.domain.BaseDeviceParam;
import com.aucma.base.service.IBaseDeviceParamService;

/**
 * 设备参数Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-19
 */
@Service
public class BaseDeviceParamServiceImpl implements IBaseDeviceParamService 
{
    @Autowired
    private BaseDeviceParamMapper baseDeviceParamMapper;

    /**
     * 查询设备参数
     * 
     * @param objId 设备参数主键
     * @return 设备参数
     */
    @Override
    public BaseDeviceParam selectBaseDeviceParamByObjId(Long objId)
    {
        return baseDeviceParamMapper.selectBaseDeviceParamByObjId(objId);
    }

    /**
     * 查询设备参数列表
     * 
     * @param baseDeviceParam 设备参数
     * @return 设备参数
     */
    @Override
    public List<BaseDeviceParam> selectBaseDeviceParamList(BaseDeviceParam baseDeviceParam)
    {
        return baseDeviceParamMapper.selectBaseDeviceParamList(baseDeviceParam);
    }

    /**
     * 新增设备参数
     * 
     * @param baseDeviceParam 设备参数
     * @return 结果
     */
    @Override
    public int insertBaseDeviceParam(BaseDeviceParam baseDeviceParam)
    {
        return baseDeviceParamMapper.insertBaseDeviceParam(baseDeviceParam);
    }

    /**
     * 修改设备参数
     * 
     * @param baseDeviceParam 设备参数
     * @return 结果
     */
    @Override
    public int updateBaseDeviceParam(BaseDeviceParam baseDeviceParam)
    {
        return baseDeviceParamMapper.updateBaseDeviceParam(baseDeviceParam);
    }

    /**
     * 批量删除设备参数
     * 
     * @param objIds 需要删除的设备参数主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceParamByObjIds(Long[] objIds)
    {
        return baseDeviceParamMapper.deleteBaseDeviceParamByObjIds(objIds);
    }

    /**
     * 删除设备参数信息
     * 
     * @param objId 设备参数主键
     * @return 结果
     */
    @Override
    public int deleteBaseDeviceParamByObjId(Long objId)
    {
        return baseDeviceParamMapper.deleteBaseDeviceParamByObjId(objId);
    }
}
