package com.aucma.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.base.domain.BaseDeviceParam;
import com.aucma.base.service.IBaseDeviceParamService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 设备参数Controller
 *
 * @author Yinq
 * @date 2023-09-19
 */
@RestController
@RequestMapping("/base/deviceParam" )
public class BaseDeviceParamController extends BaseController {
    @Autowired
    private IBaseDeviceParamService baseDeviceParamService;

/**
 * 查询设备参数列表
 */
@PreAuthorize("@ss.hasPermi('base:deviceParam:list')" )
@GetMapping("/list" )
    public TableDataInfo list(BaseDeviceParam baseDeviceParam) {
        startPage();
        List<BaseDeviceParam> list = baseDeviceParamService.selectBaseDeviceParamList(baseDeviceParam);
        return getDataTable(list);
    }

    /**
     * 导出设备参数列表
     */
    @PreAuthorize("@ss.hasPermi('base:deviceParam:export')" )
    @Log(title = "设备参数" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, BaseDeviceParam baseDeviceParam) {
        List<BaseDeviceParam> list = baseDeviceParamService.selectBaseDeviceParamList(baseDeviceParam);
        ExcelUtil<BaseDeviceParam> util = new ExcelUtil<BaseDeviceParam>(BaseDeviceParam. class);
        util.exportExcel(response, list, "设备参数数据" );
    }

    /**
     * 获取设备参数详细信息
     */
    @PreAuthorize("@ss.hasPermi('base:deviceParam:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(baseDeviceParamService.selectBaseDeviceParamByObjId(objId));
    }

    /**
     * 新增设备参数
     */
    @PreAuthorize("@ss.hasPermi('base:deviceParam:add')" )
    @Log(title = "设备参数" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseDeviceParam baseDeviceParam) {
        baseDeviceParam.setCreatedBy(getUsername());
        baseDeviceParam.setCreatedTime(DateUtils.getNowDate());
        return toAjax(baseDeviceParamService.insertBaseDeviceParam(baseDeviceParam));
    }

    /**
     * 修改设备参数
     */
    @PreAuthorize("@ss.hasPermi('base:deviceParam:edit')" )
    @Log(title = "设备参数" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseDeviceParam baseDeviceParam) {
        baseDeviceParam.setUpdatedBy(getUsername());
        baseDeviceParam.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(baseDeviceParamService.updateBaseDeviceParam(baseDeviceParam));
    }

    /**
     * 删除设备参数
     */
    @PreAuthorize("@ss.hasPermi('base:deviceParam:remove')" )
    @Log(title = "设备参数" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseDeviceParamService.deleteBaseDeviceParamByObjIds(objIds));
    }
}
